@@ -2,7 +2,7 @@ package ODS;
 
 use strict; use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use ODS::Table;
 use Blessed::Merge;
@@ -41,6 +41,9 @@ sub import {
 	YAOO::make_keyword($called, "connect", sub {
 		return $table->connect(@_);
 	});
+	YAOO::make_keyword($called, "instantiate", sub {
+		return $table->instantiate(@_);
+	});
 }
 
 =head1 NAME
@@ -49,7 +52,7 @@ ODS - Object Data Store
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -99,7 +102,7 @@ Version 0.02
 
 	...
 
-	package ResultSet::Court; 
+	package ResultSet::Court;
 
 	use YAOO;
 
@@ -108,12 +111,12 @@ Version 0.02
 	has people => isa(string);
 
 	has miss_diagnosis => isa(object);
-	
+
 	sub licenced_doctors {
 		my ($self, %name) = @_;
 
 		$self->miss_diagnosis($self->find(
-			%name	
+			%name
 		));
 	}
 
