@@ -8,9 +8,11 @@ auto_build;
 
 has table => isa(object);
 
+has serialize_class => isa(object);
+
 sub connect {
-	my ($self, @params) = @_;
-	$self = $self->new(@params);
+	my ($self, %params) = @_;
+	$self = $self->new(%params);
 	return $self;
 }
 
@@ -26,7 +28,8 @@ sub into_rows {
 			push @rows, $self->table->row_class->new(
 				table => $self->table,
 				data => $row,
-				inflated => $inflated || 0 
+				inflated => $inflated || 0,
+				serialize_class => $self->serialize_class
 			);
 		}
 		$self->table->rows(\@rows);
@@ -36,7 +39,8 @@ sub into_rows {
 		return $self->table->row_class->new(
 			table => $self->table,
 			data => $data,
-			inflated => $inflated || 0
+			inflated => $inflated || 0,
+			serialize_class => $self->serialize_class
 		);
 	}
 
@@ -47,11 +51,13 @@ sub into_storage {
 	my ($self, $all) = @_;
 
 	my $data;
-	if ($all) {
+	if ($all && !ref $all) {
 		for my $row (@{ $self->table->rows }) {
 			my $val = $row->store_row();
 			push @{$data}, $val;
 		}
+	} elsif ($all) {
+		$data = $all->store_row();
 	} else {
 		$data = $self->table->rows->[-1]->store_row();
 	}
