@@ -25,10 +25,12 @@ has field => rw, isa(hash);
 has inflated => rw, isa(boolean);
 
 sub build_column {
-	my ($self, $data, $already_inflated) = @_;
+	my ($self, $data, $already_inflated, $serialize) = @_;
 
 	$self = clone($self);
 
+	$self->serialize_class($serialize) if $serialize && $self->can('serialize_class');
+
 	$self->inflated($already_inflated);
 
 	$self->value($data);
@@ -62,13 +64,13 @@ sub inflate {
 
 	# has_validation_class
 	return $self unless not $self->inflated and $self->can('inflation');
-	
+
 	$self->value(
 		$self->inflation($self->value)
 	);
 
 	$self->inflated(1);
-	
+
 	return $self;
 }
 
@@ -87,16 +89,6 @@ sub deflate {
 	return $self;
 }
 
-sub coerce {
-	my ($self) = @_;
-	
-	return unless $self->can('coercion');
-
-	$self->value(
-		$self->coercion($self->value)
-	);
-}
-
 1;
 
 __END__
