@@ -9,15 +9,15 @@ use ODS::Utils qw/clone error/;
 has reference => isa(boolean);
 
 sub validation {
-        if (ref($_[1] || "") ne 'SCALAR' && ${$_[1]} !~ m/1|0/) {
+        if (ref($_[1] || "") ne 'SCALAR' || ${$_[1]} !~ m/1|0/) {
                 croak sprintf "The value passed to the %s column does not match the boolean constraint.",
                         $_[0]->name;
         }
-	return $_[1]; 
+	return $_[1];
 }
 
-sub inflation { 
-	my ($self, $value) = @_; 
+sub inflation {
+	my ($self, $value) = @_;
         if (! ref $value) {
 		$self->reference(\1);
                 $value = \!!$value;
@@ -29,7 +29,7 @@ sub deflation {
 	if ($self->reference && ref $value) {
 		$value = $$value;
 	}
-	return $value; 
+	return $value;
 }
 
 1;
